==> mono-2.4.3.tar.bz2: mono-2.4.3/mcs/class/System.ServiceModel/System.ServiceModel.Activation/ServiceHostFactory.cs <==
//
// ServiceHostFactory.cs
//
// Author:
//	Atsushi Enomoto <atsushi@ximian.com>
//
// Copyright (C) 2006 Novell, Inc.  http://www.novell.com
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
using System;
using System.ServiceModel;

namespace System.ServiceModel.Activation
{
	public class ServiceHostFactory : ServiceHostFactoryBase
	{
		[MonoTODO]
		public override ServiceHostBase CreateServiceHost (
			string constructorString, Uri [] baseAddresses)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO ("untested")]
		protected internal virtual ServiceHost CreateServiceHost (
			Type serviceType, Uri [] baseAddresses)
		{
			return new ServiceHost (serviceType, baseAddresses);
		}
	}
}

==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/System.ServiceModel/System.ServiceModel.Activation/ServiceHostFactory.cs <==
//
// ServiceHostFactory.cs
//
// Author:
//	Atsushi Enomoto <atsushi@ximian.com>
//
// Copyright (C) 2006 Novell, Inc.  http://www.novell.com
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
using System;
using System.ServiceModel;

namespace System.ServiceModel.Activation
{
	public class ServiceHostFactory : ServiceHostFactoryBase
	{
		[MonoTODO]
		public override ServiceHostBase CreateServiceHost (
			string constructorString, Uri [] baseAddresses)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO ("untested")]
		protected virtual ServiceHost CreateServiceHost (
			Type serviceType, Uri [] baseAddresses)
		{
			return new ServiceHost (serviceType, baseAddresses);
		}
	}
}
